====
Cats
====

It brings more cats to your life!

-------
Install
-------

.. code-block ::

    pip install cats

If you want to run parsers you need Python 3.5 or better and install special requirements:

.. code-block ::

    pip install 'cats[parser]'

----------
How to use
----------

You can do it!

.. code-block ::

    $ cats
          ,-~-,       ,-~~~~-,   /\  /\
    (\   / ,-, \   ,'        ', /  ~~  \
     \'-' /   \ \  /    _      #  <0 0> \
      '--'     \ \/    .''.    # =  Y  =/
               \     / \   \   `#-..!.-'
                \   \   \   `\ \\
                 )  />  /     \ \\
                / /`/ /`__     \ \\__
          jgs  (____)))_)))     \__)))


-------
Sources
-------

1. https://user.xmission.com/~emailbox/ascii_cats.htm
2. ...to be continued.
